@@ -24,20 +24,24 @@ class CaptchaWidget(forms.Widget):
         context = self.get_context(name, value, attrs)
         # captcha = get_captcha(value)
         captcha = get_captcha(self.attrs['value'])
+        # javascript functions don't allow "-" char
+        unique_id = name.replace("-", "_")
 
         context['image_b64'] = base64.b64encode(captcha.read()).decode()
         context['widget']['value'] = ''
         context['widget']['hidden_field'] = self.attrs['hidden_field']
+        context['widget']['unique_id'] = unique_id
 
         inline_code = mark_safe(
             '<script>'
-            'function refresh_captcha(){{'
+            'function refresh_captcha_{unique_id}(){{'
                 '$.get(location.href, function(data) {{'
                     '$("#{name}_img").attr("src",($(data).find("#{name}_img").attr("src")));'
                     '$("#{hidden_field}").val($(data).find("#{hidden_field}").val());'
                 '}});'
             '}}'
             '</script>'.format(name=name,
+                               unique_id=unique_id,
                                hidden_field=self.attrs['hidden_field'])
         )
 
